@@ -144,7 +144,12 @@ void ContactsWindow::CercaSlot()
             int index = child->objectName().toInt();
             Contact* c = m_Contacts.at(index);
             if (ui->txtCerca->text().isEmpty() || c->Name.contains(ui->txtCerca->text(), Qt::CaseInsensitive)){
-                child->setVisible(true);
+                ContactWidget* cw = (ContactWidget*)child;
+                if (ui->txtCerca->text().isEmpty())
+                    cw->SelectText(c->Name);
+                else
+                    cw->SelectText(ui->txtCerca->text());
+                cw->setVisible(true);
                 count++;
             }else
                 child->setVisible(false);
