@@ -34,18 +34,26 @@ public:
     float Scatto;
     QString DimensioneScatto;
     QDate Periodo;
-    QDate DataUtile;
+    QDate DataUtile;    
 };
 
 class Counter
 {
 public:
+    enum widgetSize
+    {
+        widgetMinimal,
+        widgetMedium,
+        widgetDetailed,
+    };
+
     Counter();
 
     QString Description;
     QString Type;
     QString Class;
     QString Code;
+    widgetSize WidgetSize;
 
     QList<SogliaItem> Soglie;
 
