@@ -27,6 +27,7 @@ Settings::Settings(QObject *parent) :
     StyleSheetName = "Default";
     ShowStandardCounters = false;
     ShowPercentage = true;
+    SaveSentSms = true;
     LogXml = false;
     SmsSent = 0;
     ShowLastData = true;    
@@ -59,6 +60,7 @@ bool Settings::Save()
     settings->setValue("logxml", LogXml);
     settings->setValue("showpercentage", ShowPercentage);
     settings->setValue("showstandardcounters", ShowStandardCounters);
+    settings->setValue("savesentsms", SaveSentSms);
 
     settings->setValue("smsdate", SmsDate);
     settings->setValue("smssent", SmsSent);
@@ -99,6 +101,7 @@ bool Settings::Load()
     LogXml = settings->value("logxml", false).toBool();
     ShowPercentage = settings->value("showpercentage", true).toBool();
     ShowStandardCounters = settings->value("showstandardcounters", false).toBool();
+    SaveSentSms = settings->value("savesentsms", true).toBool();
 
     SmsDate = settings->value("smsdate").toDate();
     SmsSent = settings->value("smssent").toInt();
