@@ -20,6 +20,10 @@
 #include <QMovie>
 #include <QRegExp>
 
+#include <glib-2.0/glib.h>
+#include <rtcom-eventlogger/eventlogger.h>
+#include <rtcom-eventlogger/event.h>
+#include <QUuid>
 #include "commonstatic.h"
 #include "captchawindow.h"
 #include "contactswindow.h"
@@ -156,6 +160,7 @@ void SmsWindow::SendSlot()
                 if (m_Vodafone->SendMessage(ui->txtReceiver->text(), ui->txtMessage->toPlainText(), captcha, &error)){
                     StopWait();
                     CommonStatic::InfoMessage(this, tr("SMS inviato"));
+                    SaveMsgToSentFolder(ui->txtReceiver->text(), ui->txtMessage->toPlainText());
 
                     if (!m_Settings->SmsDate.isValid() || m_Settings->SmsDate != QDate::currentDate()){
                         m_Settings->SmsDate = QDate::currentDate();
@@ -210,3 +215,41 @@ void SmsWindow::MessageChangedSlot()
     else
         ui->lblCharacters->setStyleSheet("color: black;");
 }
+
+bool SmsWindow::SaveMsgToSentFolder(QString number, QString message)
+{
+#ifdef Q_WS_MAEMO_5
+    RTComEl* el = rtcom_el_new();
+    bool result = false;
+    QString partNumber = number.right(7);
+
+    RTComElEvent* ev = rtcom_el_event_new();
+
+    RTCOM_EL_EVENT_SET_FIELD(ev, service, g_strdup(QString("RTCOM_EL_SERVICE_SMS").toLatin1().data()));
+    RTCOM_EL_EVENT_SET_FIELD(ev, event_type, g_strdup(QString("RTCOM_EL_EVENTTYPE_SMS_OUTBOUND").toLatin1().data()));
+    RTCOM_EL_EVENT_SET_FIELD(ev, start_time, time(NULL));
+    RTCOM_EL_EVENT_SET_FIELD(ev, end_time, time(NULL));
+    RTCOM_EL_EVENT_SET_FIELD(ev, is_read, TRUE);
+    RTCOM_EL_EVENT_SET_FIELD(ev, remote_ebook_uid, 0);
+    RTCOM_EL_EVENT_SET_FIELD(ev, local_uid, g_strdup(QString("ring/tel/ring").toLatin1().data()));
+    RTCOM_EL_EVENT_SET_FIELD(ev, local_name, g_strdup(QString("<SelfHandle>").toLatin1().data()));
+    RTCOM_EL_EVENT_SET_FIELD(ev, remote_uid, number.toLatin1().data());
+    RTCOM_EL_EVENT_SET_FIELD(ev, remote_name, g_strdup(QString("").toLatin1().data()));
+    RTCOM_EL_EVENT_SET_FIELD(ev, group_uid, g_strdup(partNumber.toLatin1().data()));
+    RTCOM_EL_EVENT_SET_FIELD(ev, free_text, g_strdup(message.toUtf8().data()));
+
+    int id = rtcom_el_add_event(el, ev, NULL);
+    if (id >= 0){
+        QUuid uid = QUuid::createUuid();
+        rtcom_el_add_header(el, id, QString("message-token").toLatin1().data(), uid.toString().toLatin1().data(), NULL);
+        result = true;
+    }
+
+    rtcom_el_event_free(ev);
+    g_object_unref(el);
+
+    return result;
+#else
+    return true;
+#endif
+}
